@@ -33,6 +33,12 @@ class BackendBase:
         result = file_fetcher.fetch_file(url, path)
         return result
 
+    async def download_file_async(self, url, path):
+        # result = await file_fetcher.fetch_file_async(url, path)
+        # return result
+        return self.download_file(url, path)
+
+
     def create_dir_if_not_exists(self, path):
         os.makedirs(os.path.split(path)[0], exist_ok=True)
     
\ No newline at end of file
