@@ -56,16 +56,19 @@ class MinioBackend(BackendBase):
             if tries >= 3:
                 return False, '下载出错'
             else:
-                url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
-                print('downloading {} -> {}'.format(url, download_path))
+                # url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
+                # print('downloading {} -> {}'.format(url, download_path))
 
-                if os.path.isfile(download_path):
-                    os.remove(download_path)
+                # if os.path.isfile(download_path):
+                #     os.remove(download_path)
 
-                self.create_dir_if_not_exists(download_path)
-                path = self.download_file(url, download_path)
-                if path:
-                    return True, download_path
+                # self.create_dir_if_not_exists(download_path)
+                # path = self.download_file(url, download_path)
+                # if path:
+                #     return True, download_path
+                ret, e = self.client.download_file(download_path, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
+                if ret:
+                    return True, e
                 return self.get(download_path, bucket, bucket_name, tries+1)
         except Exception as e:
             traceback.print_exc()
@@ -79,16 +82,20 @@ class MinioBackend(BackendBase):
             if tries >= 3:
                 return False, '下载出错'
             else:
-                url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
-                print('downloading {} -> {}'.format(url, download_path))
+                # url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
+                # print('downloading {} -> {}'.format(url, download_path))
 
-                if os.path.isfile(download_path):
-                    os.remove(download_path)
+                # if os.path.isfile(download_path):
+                #     os.remove(download_path)
 
-                self.create_dir_if_not_exists(download_path)
-                path = self.download_file(url, download_path)
-                if path:
-                    return True, download_path
+                # self.create_dir_if_not_exists(download_path)
+                # path = await self.download_file_async(url, download_path)
+                # if path:
+                #     return True, download_path
+
+                ret, e = self.client.download_file(download_path, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
+                if ret:
+                    return True, e
                 return await self.get_async(download_path, bucket, bucket_name, tries+1)
         except Exception as e:
             traceback.print_exc()
