@@ -11,7 +11,7 @@ from hamunafs.backends.base import BackendBase
 class WYSF(BackendBase):
     def __init__(self, cfg):
         key, secret, domain, default_bucket = cfg['key'], cfg['secret'], cfg['domain'], cfg['default_bucket']
-        self.client = Client(key, secret, Transport)
+        self.client = Client(key, secret, Transport, timeout=30)
         self.domain = domain
         self.default_bucket = default_bucket
 
@@ -96,7 +96,7 @@ class WYSF(BackendBase):
                 if os.path.isfile(download_path):
                     os.remove(download_path)
                 self.create_dir_if_not_exists(download_path)
-                path = self.download_file(url, download_path)
+                path = await self.download_file_async(url, download_path)
                 if path:
                     return True, download_path
                 return await self.get_async(download_path, bucket, bucket_name, tries+1)
