@@ -1,8 +1,12 @@
 from concurrent.futures import ThreadPoolExecutor
 from hamunafs.utils.singleton_wrapper import Singleton
+from aiodecorators import Semaphore
 import requests
+import httpx
 import shutil
 import traceback
+import aiofile
+import wget
 
 
 class FileFetcher(Singleton):
@@ -11,14 +15,12 @@ class FileFetcher(Singleton):
 
     def download_file(self, url, path, tries=0):
         try:
-            with requests.get(url, stream=True, timeout=10) as r:
-                with open(path, 'wb') as f:
-                    shutil.copyfileobj(r.raw, f)
+            wget.download(url, path)
         
             return path
         except Exception as e:
-            traceback.print_exc()
             if tries > 3:
+                traceback.print_exc()
                 return None
             return self.download_file(url, path, tries+1)
 
@@ -27,4 +29,18 @@ class FileFetcher(Singleton):
         result = future.result(timeout=60)
         return result
 
-file_fetcher = FileFetcher()
\ No newline at end of file
+    @Semaphore(4)
+    async def fetch_file_async(self, url, path, tries=0):
+        try:
+            async with aiofile.async_open(path, 'wb') as f:
+                async with httpx.AsyncClient(verify=False, timeout=30) as client:
+                    async with client.stream("GET", url) as resp:
+                        async for chunk in resp.aiter_raw(1024 * 1024):
+                            await f.write(chunk)
+            return path
+        except Exception as e:
+            if tries < 3:
+                return await self.fetch_file_async(url, path, tries+1)
+            return None
+
+file_fetcher = FileFetcher(workers=4)
\ No newline at end of file
