@@ -1,9 +1,7 @@
 
 import traceback
 from gnsq import Producer
-from ansq import open_connection
-from ansq.tcp.connection import ConnectionStatus
-from ansq.tcp.exceptions import ConnectionClosedError
+from ansq import open_connection, ConnectionOptions
 import asyncio
 import orjson
 import time
@@ -32,7 +30,7 @@ class MQManager(Singleton):
 
     async def _init_async(self):
         if self.async_mq:
-            self.mq = await open_connection(self.host, self.port)
+            self.mq = await open_connection(self.host, self.port, connection_options=ConnectionOptions(debug=True))
 
     def close(self):
         if not self.async_mq:
@@ -41,32 +39,39 @@ class MQManager(Singleton):
     async def close_async(self):
         try:
             if self.async_mq:
-                await self.mq.close()
-                del self.mq
+                try:
+                    await self.mq.close()
+                    del self.mq
+                except:
+                    pass
         except:
             traceback.print_exc()
 
-    async def get_mq_conn(self, tries=0):
+    async def get_mq_conn(self):
+        # async with self.connection_locker:
+            # if not hasattr(self, 'mq') or self.mq.status.is_closed:
+            #     await self._init_async()
+            #     await asyncio.sleep(0.1)
+            # else:
+            #     if not self.mq.status.is_connected:
+            #         is_timeout = False
+            #         t = time.time()
+            #         while self.mq.status.is_reconnecting:
+            #             if time.time() - t > 5:
+            #                 is_timeout = True
+            #                 break
+            #             await asyncio.sleep(0.1)
+                    
+            #         if self.mq.status.is_connected:
+            #             return self.mq
+                    
+            #         if is_timeout:
+            #             await self.close_async()
+            #             return None
         async with self.connection_locker:
-            if not hasattr(self, 'mq') or self.mq.status.is_closed:
+            if not hasattr(self, 'mq'):
                 await self._init_async()
                 await asyncio.sleep(0.1)
-            else:
-                if not self.mq.status.is_connected:
-                    is_timeout = False
-                    t = time.time()
-                    while self.mq.status.is_reconnecting:
-                        if time.time() - t > 5:
-                            is_timeout = True
-                            break
-                    
-                    if self.mq.status.is_connected:
-                        return self.mq
-                    
-                    if is_timeout:
-                        await self.close_async()
-                        return None
-        
         return self.mq
             
     def _encode_message(self, message):
@@ -80,8 +85,8 @@ class MQManager(Singleton):
         try:
             self.producer.close()
         except:
-            pass
-
+            pass 
+        
     def restart_producer(self):
         try:
             self.close_producer()
@@ -143,7 +148,6 @@ class MQManager(Singleton):
             await self.close_async()
             return await self.__mq_pub(topic, message, None, tries+1)
 
-
     async def async_publish(self, topic, message, mq=None):
         try:
             if isinstance(message, str):
