@@ -296,13 +296,18 @@ class XRedisAsync(Singleton):
         self.port = port
         self.db = db
         self.locker = threading.Lock()
-        pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_keepalive=True, retry_on_timeout=True)
+        pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_timeout=20, socket_keepalive=True, retry_on_timeout=True, health_check_interval=10)
         self.conn = coredis.StrictRedis(connection_pool=pool)
 
     async def _ping(self):
-        ret = await self.conn.ping()
-        if ret:
-            print('pinged')
+        ret = False
+        try:
+            ret = await self.conn.ping()
+            if ret:
+                print('pinged')
+        except:
+            pass
+        return ret
             
     async def __release_conn(self):
         if hasattr(self, 'conn'):
@@ -359,6 +364,13 @@ class XRedisAsync(Singleton):
             else:
                 traceback.print_exc()
 
+    async def has_lock(self, lock_id):
+        try:
+            return True, await self.get('lock_' + lock_id) is not None
+        except Exception as e:
+             traceback.print_exc()
+             return False, False
+
     async def set(self, key, val, expired=None, tries=0):
         conn = await self._get_connection()
         try:
